"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _dualListSelect = _interopRequireDefault(require("@data-driven-forms/common/dual-list-select"));

var _menu = require("@blueprintjs/core/lib/cjs/components/menu/menu.js");

var _menuItem = require("@blueprintjs/core/lib/cjs/components/menu/menuItem.js");

var _buttonGroup = require("@blueprintjs/core/lib/cjs/components/button/buttonGroup.js");

var _buttons = require("@blueprintjs/core/lib/cjs/components/button/buttons.js");

var _controlGroup = require("@blueprintjs/core/lib/cjs/components/forms/controlGroup.js");

var _inputGroup = require("@blueprintjs/core/lib/cjs/components/forms/inputGroup.js");

var _clsx = _interopRequireDefault(require("clsx"));

var _reactJss = require("react-jss");

var _formGroup = require("../form-group/form-group");

var useStyles = (0, _reactJss.createUseStyles)({
  menu: {
    height: '80%',
    overflow: 'auto'
  },
  buttonGroup: {
    justifyContent: 'center'
  },
  wrapper: {
    display: 'flex',
    justifyContent: 'space-evenly',
    minHeight: 250
  },
  '@media (max-width: 768px)': {
    wrapper: {
      flexDirection: 'column'
    }
  }
});

var List = function List(_ref) {
  var value = _ref.value,
      optionClick = _ref.optionClick,
      noOptionsTitle = _ref.noOptionsTitle,
      filterValue = _ref.filterValue,
      filterValueText = _ref.filterValueText,
      selectedValues = _ref.selectedValues,
      MenuProps = _ref.MenuProps,
      MenuItemProps = _ref.MenuItemProps;

  var _useStyles = useStyles(),
      menu = _useStyles.menu;

  return /*#__PURE__*/_react["default"].createElement(_menu.Menu, (0, _extends2["default"])({}, MenuProps, {
    className: (0, _clsx["default"])('bp3-elevation-1', menu, MenuProps.className)
  }), value.length < 1 && /*#__PURE__*/_react["default"].createElement(_menuItem.MenuItem, (0, _extends2["default"])({
    text: filterValue ? filterValueText : noOptionsTitle,
    disabled: true
  }, MenuItemProps)), value.length > 0 && value.map(function (_ref2) {
    var value = _ref2.value,
        label = _ref2.label,
        ItemMenuItemProps = _ref2.MenuItemProps;
    return /*#__PURE__*/_react["default"].createElement(_menuItem.MenuItem, (0, _extends2["default"])({
      onClick: function onClick(e) {
        return optionClick(e, value);
      },
      key: value,
      active: selectedValues.includes(value),
      text: label
    }, MenuItemProps, ItemMenuItemProps));
  }));
};

List.propTypes = {
  value: _propTypes["default"].arrayOf(_propTypes["default"].shape({
    value: _propTypes["default"].string.isRequired,
    label: _propTypes["default"].string.isRequired
  })),
  optionClick: _propTypes["default"].func.isRequired,
  noOptionsTitle: _propTypes["default"].node,
  filterValue: _propTypes["default"].string,
  filterValueText: _propTypes["default"].node,
  selectedValues: _propTypes["default"].array,
  checkboxVariant: _propTypes["default"].bool,
  MenuProps: _propTypes["default"].object,
  MenuItemProps: _propTypes["default"].object
};
List.defaultProps = {
  value: [],
  MenuProps: {},
  MenuItemProps: {}
};

var Toolbar = function Toolbar(_ref3) {
  var sortTitle = _ref3.sortTitle,
      onFilter = _ref3.onFilter,
      onSort = _ref3.onSort,
      sortDirection = _ref3.sortDirection,
      value = _ref3.value,
      placeholder = _ref3.placeholder,
      ControlGroupProps = _ref3.ControlGroupProps,
      InputGroupProps = _ref3.InputGroupProps,
      ButtonProps = _ref3.ButtonProps;
  return /*#__PURE__*/_react["default"].createElement(_controlGroup.ControlGroup, ControlGroupProps, /*#__PURE__*/_react["default"].createElement(_inputGroup.InputGroup, (0, _extends2["default"])({
    placeholder: placeholder,
    onChange: function onChange(e) {
      return onFilter(e.target.value);
    },
    value: value
  }, InputGroupProps)), /*#__PURE__*/_react["default"].createElement(_buttons.Button, (0, _extends2["default"])({
    icon: sortDirection ? 'sort-desc' : 'sort-asc',
    title: sortTitle,
    onClick: onSort
  }, ButtonProps)));
};

Toolbar.propTypes = {
  sortTitle: _propTypes["default"].node,
  onFilter: _propTypes["default"].func.isRequired,
  onSort: _propTypes["default"].func.isRequired,
  sortDirection: _propTypes["default"].bool,
  value: _propTypes["default"].string,
  placeholder: _propTypes["default"].string,
  ControlGroupProps: _propTypes["default"].object,
  InputGroupProps: _propTypes["default"].object,
  ButtonProps: _propTypes["default"].object
};
Toolbar.defaultProps = {
  ControlGroupProps: {},
  InputGroupProps: {},
  ButtonProps: {}
};

var DualListInternal = function DualListInternal(_ref4) {
  var allToRight = _ref4.allToRight,
      allToLeft = _ref4.allToLeft,
      leftTitle = _ref4.leftTitle,
      moveAllLeftTitle = _ref4.moveAllLeftTitle,
      moveAllRightTitle = _ref4.moveAllRightTitle,
      moveRightTitle = _ref4.moveRightTitle,
      moveLeftTitle = _ref4.moveLeftTitle,
      rightTitle = _ref4.rightTitle,
      noValueTitle = _ref4.noValueTitle,
      noOptionsTitle = _ref4.noOptionsTitle,
      filterOptionsTitle = _ref4.filterOptionsTitle,
      filterValueTitle = _ref4.filterValueTitle,
      filterValueText = _ref4.filterValueText,
      filterOptionsText = _ref4.filterOptionsText,
      state = _ref4.state,
      sortOptions = _ref4.sortOptions,
      filterOptions = _ref4.filterOptions,
      handleOptionsClick = _ref4.handleOptionsClick,
      leftValues = _ref4.leftValues,
      handleMoveRight = _ref4.handleMoveRight,
      handleMoveLeft = _ref4.handleMoveLeft,
      handleClearLeftValues = _ref4.handleClearLeftValues,
      handleClearRightValues = _ref4.handleClearRightValues,
      sortValues = _ref4.sortValues,
      filterValues = _ref4.filterValues,
      rightValues = _ref4.rightValues,
      handleValuesClick = _ref4.handleValuesClick,
      WrapperProps = _ref4.WrapperProps,
      LeftWrapperProps = _ref4.LeftWrapperProps,
      RightWrapperProps = _ref4.RightWrapperProps,
      ButtonGroupProps = _ref4.ButtonGroupProps,
      ToRightButtonProps = _ref4.ToRightButtonProps,
      AllToRightButtonProps = _ref4.AllToRightButtonProps,
      AllToLeftButtonProps = _ref4.AllToLeftButtonProps,
      ToLeftButtonProps = _ref4.ToLeftButtonProps,
      LeftControlGroupProps = _ref4.LeftControlGroupProps,
      LeftInputGroupProps = _ref4.LeftInputGroupProps,
      LeftButtonProps = _ref4.LeftButtonProps,
      RightControlGroupProps = _ref4.RightControlGroupProps,
      RightInputGroupProps = _ref4.RightInputGroupProps,
      RightButtonProps = _ref4.RightButtonProps,
      LeftMenuProps = _ref4.LeftMenuProps,
      LeftMenuItemProps = _ref4.LeftMenuItemProps,
      RightMenuProps = _ref4.RightMenuProps,
      RightMenuItemProps = _ref4.RightMenuItemProps;

  var _useStyles2 = useStyles(),
      buttonGroup = _useStyles2.buttonGroup,
      wrapper = _useStyles2.wrapper;

  return /*#__PURE__*/_react["default"].createElement("div", (0, _extends2["default"])({}, WrapperProps, {
    className: (0, _clsx["default"])(wrapper, WrapperProps.className)
  }), /*#__PURE__*/_react["default"].createElement("div", LeftWrapperProps, leftTitle, /*#__PURE__*/_react["default"].createElement(Toolbar, {
    sortDirection: state.sortLeftDesc,
    onSort: sortOptions,
    onFilter: filterOptions,
    value: state.filterOptions,
    placeholder: filterOptionsTitle,
    ControlGroupProps: LeftControlGroupProps,
    InputGroupProps: LeftInputGroupProps,
    ButtonProps: LeftButtonProps
  }), /*#__PURE__*/_react["default"].createElement(List, {
    optionClick: handleOptionsClick,
    value: leftValues,
    noOptionsTitle: noOptionsTitle,
    filterValue: state.filterOptions,
    filterValueText: filterOptionsText,
    selectedValues: state.selectedLeftValues,
    MenuProps: LeftMenuProps,
    MenuItemProps: LeftMenuItemProps
  })), /*#__PURE__*/_react["default"].createElement(_buttonGroup.ButtonGroup, (0, _extends2["default"])({
    vertical: true,
    alignText: "center"
  }, ButtonGroupProps, {
    className: (0, _clsx["default"])(buttonGroup, ButtonGroupProps.className)
  }), /*#__PURE__*/_react["default"].createElement(_buttons.Button, (0, _extends2["default"])({
    disabled: state.selectedLeftValues.length === 0,
    onClick: handleMoveRight,
    title: moveRightTitle,
    icon: "chevron-right"
  }, ToRightButtonProps)), allToRight && /*#__PURE__*/_react["default"].createElement(_buttons.Button, (0, _extends2["default"])({
    disabled: leftValues.length === 0,
    onClick: handleClearLeftValues,
    title: moveAllRightTitle,
    icon: "double-chevron-right"
  }, AllToRightButtonProps)), allToLeft && /*#__PURE__*/_react["default"].createElement(_buttons.Button, (0, _extends2["default"])({
    disabled: rightValues.length === 0,
    onClick: handleClearRightValues,
    title: moveAllLeftTitle,
    icon: "double-chevron-left"
  }, AllToLeftButtonProps)), /*#__PURE__*/_react["default"].createElement(_buttons.Button, (0, _extends2["default"])({
    disabled: state.selectedRightValues.length === 0,
    onClick: handleMoveLeft,
    title: moveLeftTitle,
    icon: "chevron-left"
  }, ToLeftButtonProps))), /*#__PURE__*/_react["default"].createElement("div", RightWrapperProps, rightTitle, /*#__PURE__*/_react["default"].createElement(Toolbar, {
    sortDirection: state.sortRightDesc,
    onSort: sortValues,
    onFilter: filterValues,
    value: state.filterValue,
    placeholder: filterValueTitle,
    ControlGroupProps: RightControlGroupProps,
    InputGroupProps: RightInputGroupProps,
    ButtonProps: RightButtonProps
  }), /*#__PURE__*/_react["default"].createElement(List, {
    optionClick: handleValuesClick,
    value: rightValues,
    noOptionsTitle: noValueTitle,
    filterValue: state.filterValue,
    filterValueText: filterValueText,
    selectedValues: state.selectedRightValues,
    MenuProps: RightMenuProps,
    MenuItemProps: RightMenuItemProps
  })));
};

DualListInternal.propTypes = {
  leftTitle: _propTypes["default"].node,
  rightTitle: _propTypes["default"].node,
  moveLeftTitle: _propTypes["default"].node,
  moveRightTitle: _propTypes["default"].node,
  allToLeft: _propTypes["default"].bool,
  allToRight: _propTypes["default"].bool,
  validateOnMount: _propTypes["default"].bool,
  moveAllLeftTitle: _propTypes["default"].node,
  moveAllRightTitle: _propTypes["default"].node,
  noValueTitle: _propTypes["default"].node,
  noOptionsTitle: _propTypes["default"].node,
  filterOptionsTitle: _propTypes["default"].node,
  filterValueTitle: _propTypes["default"].node,
  filterValueText: _propTypes["default"].node,
  filterOptionsText: _propTypes["default"].node,
  state: _propTypes["default"].object,
  sortOptions: _propTypes["default"].func,
  filterOptions: _propTypes["default"].func,
  handleOptionsClick: _propTypes["default"].func,
  leftValues: _propTypes["default"].array,
  handleMoveRight: _propTypes["default"].func,
  handleMoveLeft: _propTypes["default"].func,
  handleClearLeftValues: _propTypes["default"].func,
  handleClearRightValues: _propTypes["default"].func,
  sortValues: _propTypes["default"].func,
  filterValues: _propTypes["default"].func,
  rightValues: _propTypes["default"].array,
  handleValuesClick: _propTypes["default"].func,
  WrapperProps: _propTypes["default"].object,
  LeftWrapperProps: _propTypes["default"].object,
  RightWrapperProps: _propTypes["default"].object,
  ButtonGroupProps: _propTypes["default"].object,
  ToRightButtonProps: _propTypes["default"].object,
  AllToRightButtonProps: _propTypes["default"].object,
  AllToLeftButtonProps: _propTypes["default"].object,
  ToLeftButtonProps: _propTypes["default"].object,
  LeftControlGroupProps: _propTypes["default"].object,
  LeftInputGroupProps: _propTypes["default"].object,
  LeftButtonProps: _propTypes["default"].object,
  RightControlGroupProps: _propTypes["default"].object,
  RightInputGroupProps: _propTypes["default"].object,
  RightButtonProps: _propTypes["default"].object,
  LeftMenuProps: _propTypes["default"].object,
  LeftMenuItemProps: _propTypes["default"].object,
  RightMenuProps: _propTypes["default"].object,
  RightMenuItemProps: _propTypes["default"].object
};
DualListInternal.defaultProps = {
  leftTitle: 'Options',
  rightTitle: 'Selected',
  moveLeftTitle: 'Move selected to left',
  moveRightTitle: 'Move selected to right',
  moveAllRightTitle: 'Move all to right',
  moveAllLeftTitle: 'Move all to left',
  noOptionsTitle: 'No available options',
  noValueTitle: 'No selected',
  filterOptionsTitle: 'Filter options',
  filterValueTitle: 'Filter selected value',
  filterOptionsText: 'Remove your filter to see all options',
  filterValueText: 'Remove your filter to see all selected',
  options: [],
  allToLeft: true,
  allToRight: true,
  WrapperProps: {},
  LeftWrapperProps: {},
  RightWrapperProps: {},
  ButtonGroupProps: {},
  ToRightButtonProps: {},
  AllToRightButtonProps: {},
  AllToLeftButtonProps: {},
  ToLeftButtonProps: {},
  LeftControlGroupProps: {},
  LeftInputGroupProps: {},
  LeftButtonProps: {},
  RightControlGroupProps: {},
  RightInputGroupProps: {},
  RightButtonProps: {},
  LeftMenuProps: {},
  LeftMenuItemProps: {},
  RightMenuProps: {},
  RightMenuItemProps: {}
};

var DualListWrapper = function DualListWrapper(props) {
  return /*#__PURE__*/_react["default"].createElement(_formGroup.FormGroupInternal, (0, _extends2["default"])({}, props, {
    Component: DualListInternal
  }));
};

var DualListSelect = function DualListSelect(props) {
  return /*#__PURE__*/_react["default"].createElement(_dualListSelect["default"], (0, _extends2["default"])({}, props, {
    DualListSelect: DualListWrapper
  }));
};

var _default = DualListSelect;
exports["default"] = _default;